@@ -8,7 +8,6 @@ if (!check_mongo_local()) exit_file("Reason: no local MongoDB")
 if (!check_internet())    exit_file("Reason: no internet connectivity")
 if (!check_binaries())    exit_file("Reason: no binaries php or sed or perl")
 
-
 # create database object
 dbc <- nodbi::src_mongo(
   db = mongo_local_rw_db,
@@ -16,13 +15,16 @@ dbc <- nodbi::src_mongo(
   url = "mongodb://localhost")
 
 #### CTGOV ####
-source("ctrdata_ctgov.R", local = TRUE)
-
-#### close ####
-try({
-  dbc$con$drop()
-  dbc$con$disconnect()
-},
-silent = TRUE)
-
-
+tf <- function() {
+  # register clean-up
+  on.exit(expr = {
+    try({
+      dbc$con$drop()
+      dbc$con$disconnect()
+    },
+    silent = TRUE)
+  })
+  # do tests
+  source("ctrdata_ctgov.R", local = TRUE)
+}
+tf()
